@@ -217,7 +217,8 @@ Change* TextUndoStack::giveChange(Change* change, int coalesceId )
     ChangeGroup* group = undoGroupStack_.isEmpty() ? 0 : undoGroupStack_.top();
 
     int lastCoalesceId = lastCoalesceIdAtCurrentLevel();
-    bool merge = lastCoalesceId && lastCoalesceIdStack_.top() == coalesceId;
+    bool merge = lastCoalesceId && lastCoalesceIdStack_.top() == coalesceId && coalesceId != CoalesceId_None;
+
     setLastCoalesceIdAtCurrentLevel(coalesceId);
     if( coalesceId == CoalesceId_ForceMerge ) { merge = true; }
 
@@ -242,7 +243,6 @@ Change* TextUndoStack::giveChange(Change* change, int coalesceId )
     // normal operation
     //-----------------
     } else {
-
         // get the optional controller context
         TextEditorController* controller = change->controllerContext();
         clearRedo( controller );
@@ -483,7 +483,7 @@ int TextUndoStack::persistedIndex()
 /// makes a dump of the current stack
 QString TextUndoStack::dumpStack()
 {
-    QString result = "";
+    QString result;
     result += "\n";
     result +="UndoStack\n";
     result += "=====================\n";
@@ -511,17 +511,17 @@ QString TextUndoStack::dumpStack()
         QMap<TextEditorController*, int>::iterator itr;
         for( itr = controllerIndexMap_.begin(); itr != controllerIndexMap_.end(); ++itr ) {
             if( itr.value() == i ) {
-                pointers.append( QString("<=(%1) ").arg( QString::number((quintptr)itr.key(),16) ) );
+                pointers.append( QStringLiteral("<=(%1) ").arg( QString::number((quintptr)itr.key(),16) ) );
             }
         }
         if( changeIndex_ == i ) {
-            pointers.append( QString("<=(DOC) " ));
+            pointers.append( QStringLiteral("<=(DOC) " ));
         }
         if( persistedIndex_ == i ){
-            pointers.append( QString("<=(P) " ));
+            pointers.append( QStringLiteral("<=(P) " ));
         }
 
-        result += QString("-|%1:%2| %3\n").arg(changeName,-30).arg(controllerName,10).arg(pointers);
+        result += QStringLiteral("-|%1:%2| %3\n").arg(changeName,-30).arg(controllerName,10).arg(pointers);
         end=false;
     }
     return result;
@@ -532,7 +532,7 @@ QString TextUndoStack::dumpStack()
 void TextUndoStack::dumpStackInternal()
 {
 #ifdef DUMP_UNDO_STACK
-    qlog_info() << dumpStack();
+    qDebug().noquote() << this->dumpStack();
 #endif
 }
 
