@@ -5,6 +5,8 @@
 
 #include "texteditorcomponent.h"
 
+#include <QApplication>
+#include <QClipboard>
 #include <QMenu>
 #include <QPainter>
 #include <QPaintEvent>
@@ -215,7 +217,7 @@ bool TextEditorComponent::event(QEvent* event)
 {
     // keypress event
     if( event->type() == QEvent::KeyPress ) {
-        QKeyEvent* keyEvent = dynamic_cast<QKeyEvent*>(event);
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
         if( keyEvent ) {
             int key = keyEvent->key();
             if( key == Qt::Key_Tab || key == Qt::Key_Backtab ) {
@@ -238,7 +240,6 @@ void TextEditorComponent::keyPressEvent(QKeyEvent* event)
     // unkown key return or control key
     if( key == Qt::Key_unknown ) { return; }
     if(key == Qt::Key_Control || key == Qt::Key_Shift || key == Qt::Key_Alt || key == Qt::Key_Meta) { return; }
-
     // convert the key to a string
     Qt::KeyboardModifiers modifiers = event->modifiers();
     if(modifiers & Qt::ShiftModifier)    key += Qt::SHIFT;
@@ -279,9 +280,11 @@ void TextEditorComponent::keyPressEvent(QKeyEvent* event)
     // not partial, not found, clear the mark
     lastKeySequence_ = QKeySequence();
 
+
     // else replace the selection if there's a text
     QString text = event->text();
-    bool specialKey =(modifiers&(Qt::MetaModifier|Qt::ControlModifier));
+    bool specialKey = (modifiers&(Qt::MetaModifier|Qt::ControlModifier))
+                  && ((modifiers!=(Qt::AltModifier|Qt::ControlModifier)) || (!text.isEmpty() && text.at(0).isUpper()));
     if( !text.isEmpty() && !specialKey ) {
         // last character is used for "undo-group after" space support
         if( this->config()->undoGroupPerSpace() ) {
@@ -292,6 +295,7 @@ void TextEditorComponent::keyPressEvent(QKeyEvent* event)
         lastCharacter_ = text;
         controller()->replaceSelection( text, CoalesceId_AppendChar );
         controller()->updateStatusText();
+        emit textKeyPressed();
     } else {
         QWidget::keyPressEvent(event);
     }
@@ -333,7 +337,7 @@ void TextEditorComponent::inputMethodEvent( QInputMethodEvent* m )
     /// TODO: Honer the arguments
     QString str;
     foreach( QInputMethodEvent::Attribute attr, m->attributes() ) {
-        str.append( QString("[%1,%2-%3,%4]").arg(attr.type).arg(attr.start).arg(attr.length).arg(attr.value.toString()) );
+        str.append( QStringLiteral("[%1,%2-%3,%4]").arg(attr.type).arg(attr.start).arg(attr.length).arg(attr.value.toString()) );
     }
 //    qlog_info() << "inputMethodEvent: commitStr=" << m->commitString() << ", preEditStr=" << m->preeditString() << ", start=" << m->replacementStart() << ", length" << m->replacementStart()  << " | " << str;
 */
@@ -365,7 +369,7 @@ QVariant TextEditorComponent::inputMethodQuery( Qt::InputMethodQuery p ) const
 /// @param event the mouse event
 void TextEditorComponent::mousePressEvent(QMouseEvent* event)
 {
-    if( event->button() == Qt::LeftButton ) {
+    if( event->button() == Qt::LeftButton || event->button() == Qt::MidButton ) {
         TextRenderer* renderer = textRenderer();
 
 //        int x = renderer->widgetXToXpos( event->x() + horizontalScrollBar()->value() );
@@ -376,16 +380,43 @@ void TextEditorComponent::mousePressEvent(QMouseEvent* event)
         int line = renderer->rawLineIndexForYpos( y );
         int col = renderer->columnIndexForXpos( line, x );
 
-        if( event->modifiers()&Qt::ControlModifier ) {
-            controller()->addCaretAt( line, col );
-        } else {
-            controller()->moveCaretTo( line, col, event->modifiers()&Qt::ShiftModifier );
+        if( event->button() == Qt::LeftButton ) {
+            if( event->modifiers()&Qt::ControlModifier ) {
+                controller()->addCaretAt( line, col );
+            } else {
+                controller()->moveCaretTo( line, col, event->modifiers()&Qt::ShiftModifier );
+            }
+        }
+        if( QApplication::clipboard()->supportsSelection() && event->button() == Qt::MidButton ) { // X11 / linux support middle button paste
+            controller()->moveCaretTo( line, col, false ); // clear actual selection and put cursor under mouse
+            controller()->replaceSelection( QApplication::clipboard()->text(QClipboard::Selection), CoalesceId_Paste );
+            controller()->updateStatusText();
         }
     }
     QWidget::mousePressEvent(event);
 }
 
 
+/// A mouse release happens
+///
+/// Only used to copy selection to selection clipboard for X11 / linux systems
+///
+/// @param event the mouse event
+void TextEditorComponent::mouseReleaseEvent(QMouseEvent *event)
+{
+    if( QApplication::clipboard()->supportsSelection() && event->button() == Qt::LeftButton ) {
+        if( controller()->textSelection()->rangeCount() == 1 ) {
+            QString selection;
+            selection = controller()->textSelection()->getSelectedText();
+            if( !selection.isEmpty() ) {
+                QApplication::clipboard()->setText(selection, QClipboard::Selection);
+            }
+        }
+    }
+    QWidget::mouseReleaseEvent(event);
+}
+
+
 /// A mouse double click happens
 /// @param event the mouse double click that occured
 void TextEditorComponent::mouseDoubleClickEvent( QMouseEvent* event )
