@@ -136,7 +136,6 @@ public:
 
     void setIsAutologin(bool b) { mIsAutologin = b; }
     bool isAutologin() { return mIsAutologin; }
-    void setReplacementCommand(const QString&);
     void registerEventHandler(const QString&, TScript*);
     void registerAnonymousEventHandler(const QString& name, const QString& fun);
     void unregisterEventHandler(const QString&, TScript*);
@@ -147,6 +146,9 @@ public:
     void stopAllTriggers();
     void reenableAllTriggers();
 
+    // get Search Engine
+    QPair<QString, QString> getSearchEngine();
+
     void set_USE_IRE_DRIVER_BUGFIX(bool b)
     {
         mUSE_IRE_DRIVER_BUGFIX = b;
@@ -248,6 +250,10 @@ public:
     // code editor theme file on disk for edbee to load
     QString mEditorThemeFile;
 
+    // search engine URL prefix to search query
+    QMap<QString, QString> mSearchEngineData;
+    QString mSearchEngineName;
+
     // trigger/alias/script/etc ID whose Lua code to show when previewing a theme
     // remembering this value to show what the user has selected does have its
     // flaws in case of items getting created/deleted, but this is just a
@@ -359,11 +365,6 @@ private:
     QStringList mParagraphList;
 
     int mPort;
-    QString mPrompt;
-
-    QString mReplacementCommand;
-
-    QString mRest;
 
     int mRetries;
     bool mSaveProfileOnExit;
