@@ -80,12 +80,12 @@ void KeyUnit::compileAll()
 
 TKey* KeyUnit::findKey(QString& name)
 {
-    QMap<QString, TKey*>::const_iterator it = mLookupTable.find(name);
-    while (it != mLookupTable.end() && it.key() == name) {
+    QMap<QString, TKey*>::const_iterator it = mLookupTable.constFind(name);
+    while (it != mLookupTable.cend() && it.key() == name) {
         TKey* pT = it.value();
         return pT;
     }
-    return 0;
+    return nullptr;
 }
 
 bool KeyUnit::enableKey(const QString& name)
@@ -174,13 +174,11 @@ void KeyUnit::reParentKey(int childID, int oldParentID, int newParentID, int par
     }
     if (pNewParent) {
         pNewParent->addChild(pChild, parentPosition, childPosition);
-        if (pChild) {
-            pChild->setParent(pNewParent);
-        }
+        pChild->setParent(pNewParent);
         //cout << "dumping family of newParent:"<<endl;
         //pNewParent->Dump();
     } else {
-        pChild->Tree<TKey>::setParent(0);
+        pChild->Tree<TKey>::setParent(nullptr);
         addKeyRootNode(pChild, parentPosition, childPosition);
     }
 }
@@ -205,7 +203,7 @@ TKey* KeyUnit::getKey(int id)
     if (mKeyMap.find(id) != mKeyMap.end()) {
         return mKeyMap.value(id);
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -215,7 +213,7 @@ TKey* KeyUnit::getKeyPrivate(int id)
     if (mKeyMap.find(id) != mKeyMap.end()) {
         return mKeyMap.value(id);
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
