@@ -31,7 +31,7 @@
 #include "mudlet.h"
 
 #include "pre_guard.h"
-#include <QRegExp>
+#include <QRegularExpression>
 #include "post_guard.h"
 
 #include <assert.h>
@@ -72,11 +72,12 @@ TTrigger::TTrigger( TTrigger * parent, Host * pHost )
 , mModuleMember(false)
 , mColorTriggerFgAnsi()
 , mColorTriggerBgAnsi()
+, mRegisteredAnonymousLuaFunction(false)
 {
 }
 
 TTrigger::TTrigger(const QString& name, QStringList regexList, QList<int> regexProperyList, bool isMultiline, Host* pHost)
-: Tree<TTrigger>(0)
+: Tree<TTrigger>(nullptr)
 , mTriggerContainsPerlRegex( false )
 , mPerlSlashGOption( false )
 , mFilterTrigger( false )
@@ -106,6 +107,7 @@ TTrigger::TTrigger(const QString& name, QStringList regexList, QList<int> regexP
 , mModuleMember(false)
 , mColorTriggerFgAnsi()
 , mColorTriggerBgAnsi()
+, mRegisteredAnonymousLuaFunction(false)
 {
     setRegexCodeList(regexList, regexProperyList);
 }
@@ -158,7 +160,7 @@ bool TTrigger::setRegexCodeList(QStringList regexList, QList<int> propertyList)
     bool state = true;
 
     for (int i = 0; i < regexList.size(); i++) {
-        if (regexList[i].size() < 1) {
+        if (regexList.at(i).isEmpty() && propertyList.at(i) != REGEX_PROMPT) {
             continue;
         }
 
@@ -171,7 +173,7 @@ bool TTrigger::setRegexCodeList(QStringList regexList, QList<int> propertyList)
 
             int erroffset;
 
-            QSharedPointer<pcre> re(pcre_compile(local8Bit.constData(), 0, &error, &erroffset, 0), pcre_deleter);
+            QSharedPointer<pcre> re(pcre_compile(local8Bit.constData(), 0, &error, &erroffset, nullptr), pcre_deleter);
 
             if (!re) {
                 if (mudlet::debugMode) {
@@ -211,23 +213,27 @@ bool TTrigger::setRegexCodeList(QStringList regexList, QList<int> propertyList)
         }
 
         if (propertyList[i] == REGEX_COLOR_PATTERN) {
-            QRegExp regex = QRegExp(R"(FG(\d+)BG(\d+))");
-            int _pos = regex.indexIn(regexList[i]);
+            QRegularExpression regex = QRegularExpression(QStringLiteral(R"(FG(\d+)BG(\d+))"));
+            QRegularExpressionMatch match = regex.match(regexList[i]);
+
+            int _pos = match.capturedStart();
+
             if (_pos == -1) {
-                mColorPatternList.push_back(0);
+                mColorPatternList.push_back(nullptr);
                 state = false;
                 continue;
             }
-            int ansiFg = regex.cap(1).toInt();
-            int ansiBg = regex.cap(2).toInt();
+
+            int ansiFg = match.captured(1).toInt();
+            int ansiBg = match.captured(2).toInt();
 
             if (!setupColorTrigger(ansiFg, ansiBg)) {
-                mColorPatternList.push_back(0);
+                mColorPatternList.push_back(nullptr);
                 state = false;
                 continue;
             }
         } else {
-            mColorPatternList.push_back(0);
+            mColorPatternList.push_back(nullptr);
         }
     }
     if (!state) {
@@ -265,7 +271,7 @@ bool TTrigger::match_perl(char* subject, const QString& toMatch, int regexNumber
     std::list<int> posList;
     int ovector[300]; // 100 capture groups max (can be increase nbGroups=1/3 ovector
 
-    rc = pcre_exec(re.data(), 0, subject, subject_length, 0, 0, ovector, 100);
+    rc = pcre_exec(re.data(), nullptr, subject, subject_length, 0, 0, ovector, 100);
 
     if (rc < 0) {
         return false;
@@ -298,15 +304,15 @@ bool TTrigger::match_perl(char* subject, const QString& toMatch, int regexNumber
             TDebug(QColor(Qt::darkMagenta), QColor(Qt::black)) << "<" << match.c_str() << ">\n" >> 0;
         }
     }
-    pcre_fullinfo(re.data(), NULL, PCRE_INFO_NAMECOUNT, &namecount);
+    pcre_fullinfo(re.data(), nullptr, PCRE_INFO_NAMECOUNT, &namecount);
 
     if (namecount <= 0) {
-        ;
+        ;// Do something?
     } else {
         unsigned char* tabptr;
-        pcre_fullinfo(re.data(), NULL, PCRE_INFO_NAMETABLE, &name_table);
+        pcre_fullinfo(re.data(), nullptr, PCRE_INFO_NAMETABLE, &name_table);
 
-        pcre_fullinfo(re.data(), NULL, PCRE_INFO_NAMEENTRYSIZE, &name_entry_size);
+        pcre_fullinfo(re.data(), nullptr, PCRE_INFO_NAMEENTRYSIZE, &name_entry_size);
 
         tabptr = name_table;
         for (i = 0; i < namecount; i++) {
@@ -328,7 +334,7 @@ bool TTrigger::match_perl(char* subject, const QString& toMatch, int regexNumber
             options = PCRE_NOTEMPTY | PCRE_ANCHORED;
         }
 
-        rc = pcre_exec(re.data(), NULL, subject, subject_length, start_offset, options, ovector, 30);
+        rc = pcre_exec(re.data(), nullptr, subject, subject_length, start_offset, options, ovector, 30);
 
         if (rc == PCRE_ERROR_NOMATCH) {
             if (options == 0) {
@@ -439,7 +445,7 @@ bool TTrigger::match_begin_of_line_substring(const QString& toMatch, const QStri
     if (toMatch.startsWith(regex)) {
         std::list<std::string> captureList;
         std::list<int> posList;
-        captureList.push_back(regex.toLatin1().data());
+        captureList.emplace_back(regex.toLatin1().data());
         posList.push_back(0 + posOffset);
         if (mudlet::debugMode) {
             TDebug(QColor(Qt::darkCyan), QColor(Qt::black)) << "Trigger name=" << mName << "(" << mRegexCodeList.value(regexNumber) << ") matched.\n" >> 0;
@@ -539,11 +545,11 @@ bool TTrigger::match_substring(const QString& toMatch, const QString& regex, int
     if (where != -1) {
         std::list<std::string> captureList;
         std::list<int> posList;
-        captureList.push_back(regex.toLatin1().data());
+        captureList.emplace_back(regex.toLatin1().data());
         posList.push_back(where + posOffset);
         if (mPerlSlashGOption) {
             while ((where = toMatch.indexOf(regex, where + 1)) != -1) {
-                captureList.push_back(regex.toLatin1().data());
+                captureList.emplace_back(regex.toLatin1().data());
                 posList.push_back(where + posOffset);
             }
         }
@@ -744,6 +750,24 @@ bool TTrigger::match_lua_code(int regexNumber)
     return false;
 }
 
+bool TTrigger::match_prompt(int patternNumber)
+{
+    if (mpHost->mpConsole->mIsPromptLine) {
+        if (mudlet::debugMode) {
+            TDebug(QColor(Qt::yellow), QColor(Qt::black)) << "Trigger name=" << mName << "(" << mRegexCodeList.value(patternNumber) << ") matched.\n" >> 0;
+        }
+        if (mIsMultiline) {
+            std::list<std::string> captureList;
+            std::list<int> posList;
+            updateMultistates(patternNumber, captureList, posList);
+            return true;
+        }
+        execute();
+        return true;
+    }
+    return false;
+}
+
 bool TTrigger::match_exact_match(const QString& toMatch, const QString& line, int regexNumber, int posOffset)
 {
     QString text = toMatch;
@@ -753,7 +777,7 @@ bool TTrigger::match_exact_match(const QString& toMatch, const QString& line, in
     if (text == line) {
         std::list<std::string> captureList;
         std::list<int> posList;
-        captureList.push_back(line.toLatin1().data());
+        captureList.emplace_back(line.toLatin1().data());
         posList.push_back(0 + posOffset);
         if (mudlet::debugMode) {
             TDebug(QColor(Qt::yellow), QColor(Qt::black)) << "Trigger name=" << mName << "(" << mRegexCodeList.value(regexNumber) << ") matched.\n" >> 0;
@@ -831,38 +855,42 @@ bool TTrigger::match(char* subject, const QString& toMatch, int line, int posOff
         }
 
         int size = mRegexCodePropertyList.size();
-        for (int i = 0;; i++) {
-            if (i >= size) {
+        for (int patternNumber = 0;; patternNumber++) {
+            if (patternNumber >= size) {
                 break;
             }
             ret = false;
-            switch (mRegexCodePropertyList.value(i)) {
+            switch (mRegexCodePropertyList.value(patternNumber)) {
             case REGEX_SUBSTRING:
-                ret = match_substring(toMatch, mRegexCodeList[i], i, posOffset);
+                ret = match_substring(toMatch, mRegexCodeList[patternNumber], patternNumber, posOffset);
                 break;
 
             case REGEX_PERL:
-                ret = match_perl(subject, toMatch, i, posOffset);
+                ret = match_perl(subject, toMatch, patternNumber, posOffset);
                 break;
 
             case REGEX_BEGIN_OF_LINE_SUBSTRING:
-                ret = match_begin_of_line_substring(toMatch, mRegexCodeList[i], i, posOffset);
+                ret = match_begin_of_line_substring(toMatch, mRegexCodeList[patternNumber], patternNumber, posOffset);
                 break;
 
             case REGEX_EXACT_MATCH:
-                ret = match_exact_match(toMatch, mRegexCodeList[i], i, posOffset);
+                ret = match_exact_match(toMatch, mRegexCodeList[patternNumber], patternNumber, posOffset);
                 break;
 
             case REGEX_LUA_CODE:
-                ret = match_lua_code(i);
+                ret = match_lua_code(patternNumber);
                 break;
 
             case REGEX_LINE_SPACER:
-                ret = match_line_spacer(i);
+                ret = match_line_spacer(patternNumber);
                 break;
 
             case REGEX_COLOR_PATTERN:
-                ret = match_color_pattern(line, i);
+                ret = match_color_pattern(line, patternNumber);
+                break;
+
+            case REGEX_PROMPT:
+                ret = match_prompt(patternNumber);
                 break;
             }
             // policy: one match is enough to fire on OR-trigger, but in the case of
@@ -874,7 +902,7 @@ bool TTrigger::match(char* subject, const QString& toMatch, int line, int posOff
                     break;
                 }
             } else {
-                if ((!ret) && (i >= highestCondition)) {
+                if ((!ret) && (patternNumber >= highestCondition)) {
                     break;
                 }
             }
@@ -1171,12 +1199,12 @@ TColorTable* TTrigger::createColorPattern(int ansiFg, int ansiBg)
     }
 
     if (invalidColorCode) {
-        return 0;
+        return nullptr;
     }
 
     auto pCT = new TColorTable;
     if (!pCT) {
-        return 0;
+        return nullptr;
     }
 
     pCT->ansiBg = ansiBg;
@@ -1265,8 +1293,13 @@ void TTrigger::compile()
 bool TTrigger::setScript(const QString& script)
 {
     mScript = script;
-    mNeedsToBeCompiled = true;
-    mOK_code = compileScript();
+    if (script.isEmpty()) {
+        mNeedsToBeCompiled = false;
+        mOK_code = true;
+    } else {
+        mNeedsToBeCompiled = true;
+        mOK_code = compileScript();
+    }
     return mOK_code;
 }
 
@@ -1299,6 +1332,16 @@ void TTrigger::execute()
             return;
         }
     }
+
+    if (mRegisteredAnonymousLuaFunction) {
+        mpLua->call_luafunction(this);
+        return;
+    }
+
+    if (mScript.isEmpty()) {
+        return;
+    }
+
     if (mIsMultiline) {
         mpLua->callMulti(mFuncName, mName);
     } else {
@@ -1334,5 +1377,5 @@ TTrigger* TTrigger::killTrigger(const QString& name)
     for (auto trigger : *mpMyChildrenList) {
         trigger->killTrigger(name);
     }
-    return 0;
+    return nullptr;
 }
