@@ -68,7 +68,7 @@ cTelnet::cTelnet(Host* pH)
 , mAlertOnNewData(true)
 , mGA_Driver(false)
 , mFORCE_GA_OFF(false)
-, mpComposer(0)
+, mpComposer(nullptr)
 , mpHost(pH)
 , mpPostingTimer(new QTimer(this))
 , mUSE_IRE_DRIVER_BUGFIX(false)
@@ -555,7 +555,7 @@ void cTelnet::processTelnetCommand(const string& command)
     case TN_WILL: {
         //server wants to enable some option (or he sends a timing-mark)...
         option = command[2];
-        int idxOption = static_cast<int>(option);
+        const auto idxOption = static_cast<int>(option);
 
         if (option == static_cast<char>(25)) //EOR support (END OF RECORD=TN_GA
         {
@@ -949,10 +949,8 @@ void cTelnet::processTelnetCommand(const string& command)
                     mpHost->mpConsole->print("<package is already installed>\n");
                     return;
                 }
-                QString _home = QDir::homePath();
-                _home.append("/.config/mudlet/profiles/");
-                _home.append(mpHost->getName());
-                mServerPackage = QString("%1/%2").arg(_home, fileName);
+
+                mServerPackage = mudlet::getMudletPath(mudlet::profileDataItemPath, mpHost->getName(), fileName);
 
                 QNetworkReply* reply = mpDownloader->get(QNetworkRequest(QUrl(url)));
                 mpProgressDialog = new QProgressDialog("downloading game GUI from server", "Abort", 0, 4000000, mpHost->mpConsole);
@@ -967,12 +965,13 @@ void cTelnet::processTelnetCommand(const string& command)
 
         // GMCP
         if (option == static_cast<char>(201)) {
-            QString _m = command.c_str();
+            QString rawPayload = command.c_str();
             if (command.size() < 6) {
                 return;
             }
-            _m = _m.mid(3, command.size() - 5);
-            setGMCPVariables(_m);
+            // strip first 3 characters to get rid of <IAC><SB><201>
+            // and strip the last 2 characters to get rid of <IAC><TN_SE>
+            setGMCPVariables(rawPayload.mid(3, rawPayload.size() - 5));
             return;
         }
 
@@ -1170,10 +1169,8 @@ void cTelnet::setGMCPVariables(const QString& msg)
             mpHost->mpConsole->print("<package is already installed>\n");
             return;
         }
-        QString _home = QDir::homePath();
-        _home.append("/.config/mudlet/profiles/");
-        _home.append(mpHost->getName());
-        mServerPackage = QString("%1/%2").arg(_home, fileName);
+
+        mServerPackage = mudlet::getMudletPath(mudlet::profileDataItemPath, mpHost->getName(), fileName);
 
         QNetworkReply* reply = mpDownloader->get(QNetworkRequest(QUrl(url)));
         mpProgressDialog = new QProgressDialog("downloading game GUI from server", "Abort", 0, 4000000, mpHost->mpConsole);
@@ -1206,7 +1203,7 @@ void cTelnet::atcpComposerCancel()
         return;
     }
     mpComposer->close();
-    mpComposer = 0;
+    mpComposer = nullptr;
     string msg = "*q\nno\n";
     socketOutRaw(msg);
 }
@@ -1250,7 +1247,7 @@ void cTelnet::atcpComposerSave(QString txt)
         return;
     }
     mpComposer->close();
-    mpComposer = 0;
+    mpComposer = nullptr;
 }
 
 // Revamped to take additional [ WARN ], [ ALERT ] and [ INFO ] prefixes and to indent
@@ -1573,11 +1570,6 @@ void cTelnet::_loadReplay()
 
         char* pB = &loadBuffer[0];
         loadedBytes = replayStream.readRawData(pB, amount);
-        qDebug("_loadReplay(): loaded: %i/%i bytes, wait for %1.3f seconds. (Single shot duration is: %1.3f seconds.)",
-               loadedBytes,
-               amount,
-               offset / 1000.0,
-               offset / (1000.0 * mudlet::self()->mReplaySpeed));
         loadBuffer[loadedBytes] = '\0'; // Previous use of loadedBytes + 1 caused a spurious character at end of string display by a qDebug of the loadBuffer contents
         mudlet::self()->mReplayTime = mudlet::self()->mReplayTime.addMSecs(offset);
         QTimer::singleShot(offset / mudlet::self()->mReplaySpeed, this, SLOT(readPipe()));
@@ -1596,13 +1588,9 @@ void cTelnet::readPipe()
     int datalen = loadedBytes;
     string cleandata = "";
     recvdGA = false;
-    qDebug(R"(Replay data: "%s")", loadBuffer);
     for (int i = 0; i < datalen; i++) {
         char ch = loadBuffer[i];
         if (iac || iac2 || insb || (ch == TN_IAC)) {
-#ifdef DEBUG
-            qDebug() << " SERVER sends telnet command " << (quint8)ch;
-#endif
             if (!(iac || iac2 || insb) && (ch == TN_IAC)) {
                 iac = true;
                 command += ch;
