@@ -39,9 +39,6 @@
 #include <QStringBuilder>
 #include "post_guard.h"
 
-
-#define _DEBUG_
-
 dlgConnectionProfiles::dlgConnectionProfiles(QWidget * parent)
 : QDialog( parent )
 , mProfileList( QStringList() )
@@ -221,7 +218,7 @@ void dlgConnectionProfiles::slot_update_port(const QString ignoreBlank)
         return;
     }
 
-    if (port.indexOf(QRegExp(QStringLiteral("^\\d+$")), 0) == -1) {
+    if (port.indexOf(QRegularExpression(QStringLiteral("^\\d+$")), 0) == -1) {
         QString val = port;
         val.chop(1);
         port_entry->setText(val);
@@ -336,11 +333,12 @@ void dlgConnectionProfiles::slot_save_name()
 
         pItem->setText(newProfileName);
 
-        QDir currentPath(QStringLiteral("%1/.config/mudlet/profiles/%2").arg(QDir::homePath(), currentProfileEditName));
+        QDir currentPath(mudlet::getMudletPath(mudlet::profileHomePath, currentProfileEditName));
         QDir dir;
 
         if (currentPath.exists()) {
-            QDir parentpath(QStringLiteral("%1/.config/mudlet/profiles/").arg(QDir::homePath()));
+            // CHECKME: previous code specified a path ending in a '/'
+            QDir parentpath(mudlet::getMudletPath(mudlet::profilesPath));
             if (!parentpath.rename(currentProfileEditName, newProfileName)) {
                 notificationArea->show();
                 notificationAreaIconLabelWarning->show();
@@ -349,7 +347,7 @@ void dlgConnectionProfiles::slot_save_name()
                 notificationAreaMessageBox->show();
                 notificationAreaMessageBox->setText(tr("Could not rename your profile data on the computer."));
             }
-        } else if (!dir.mkpath(QStringLiteral("%1/.config/mudlet/profiles/%2").arg(QDir::homePath(), newProfileName))) {
+        } else if (!dir.mkpath(mudlet::getMudletPath(mudlet::profileHomePath, newProfileName))) {
             notificationArea->show();
             notificationAreaIconLabelWarning->show();
             notificationAreaIconLabelError->hide();
@@ -358,72 +356,86 @@ void dlgConnectionProfiles::slot_save_name()
             notificationAreaMessageBox->setText(tr("Could not create the new profile folder on your computer."));
         }
 
-        // code stolen from fillout_form, should be moved to its own function
-        QFont font(QStringLiteral("Bitstream Vera Sans Mono"), 1, QFont::Normal);
-        // Some uses of QFont have a third argument such as QFont::Helvetica or
-        // QFont::Courier but that is not a valid value for that argument - it
-        // is a font weight and typically only QFont::Normal or QFont::Bold is
-        // correct there (or a number 0 to 99, the two given are 50 and 75
-        // respectively)
+        // if this was a previously deleted profile, restore it
+        auto &settings = *mudlet::self()->mpSettings;
+        auto deletedDefaultMuds = settings.value(QStringLiteral("deletedDefaultMuds"), QStringList()).toStringList();
+        if (deletedDefaultMuds.contains(newProfileName)) {
+            deletedDefaultMuds.removeOne(newProfileName);
+            settings.setValue(QStringLiteral("deletedDefaultMuds"), deletedDefaultMuds);
+            // run fillout_form to re-create the default profile icon and description
+            fillout_form();
+            // and re-select the profile since focus is lost
+            auto newProfileIcon = profiles_tree_widget->findItems(newProfileName, Qt::MatchExactly).first();
+            profiles_tree_widget->setCurrentItem(newProfileIcon);
+            slot_item_clicked(newProfileIcon);
+        } else {
+            // code stolen from fillout_form, should be moved to its own function
+            QFont font(QStringLiteral("Bitstream Vera Sans Mono"), 1, QFont::Normal);
+            // Some uses of QFont have a third argument such as QFont::Helvetica or
+            // QFont::Courier but that is not a valid value for that argument - it
+            // is a font weight and typically only QFont::Normal or QFont::Bold is
+            // correct there (or a number 0 to 99, the two given are 50 and 75
+            // respectively)
 
-        QString sList = newProfileName;
-        QString s = newProfileName;
-        pItem->setFont(font);
-        pItem->setForeground(QColor(Qt::white));
-        profiles_tree_widget->addItem(pItem);
-        QPixmap pb(120, 30);
-        pb.fill(Qt::transparent);
-        uint hash = qHash(sList);
-        QLinearGradient shade(0, 0, 120, 30);
-        int i = row;
-        quint8 i1 = hash % 255;
-        quint8 i2 = (hash + i) % 255;
-        quint8 i3 = (i * hash) % 255;
-        quint8 i4 = (3 * hash) % 255;
-        quint8 i5 = (hash) % 255;
-        quint8 i6 = (hash / (i + 2)) % 255; // Under some corner cases i might be -1 or 0
-        shade.setColorAt(1, QColor(i1, i2, i3, 255));
-        shade.setColorAt(0, QColor(i4, i5, i6, 255));
+            QString sList = newProfileName;
+            QString s = newProfileName;
+            pItem->setFont(font);
+            pItem->setForeground(QColor(Qt::white));
+            profiles_tree_widget->addItem(pItem);
+            QPixmap pb(120, 30);
+            pb.fill(Qt::transparent);
+            uint hash = qHash(sList);
+            QLinearGradient shade(0, 0, 120, 30);
+            int i = row;
+            quint8 i1 = hash % 255;
+            quint8 i2 = (hash + i) % 255;
+            quint8 i3 = (i * hash) % 255;
+            quint8 i4 = (3 * hash) % 255;
+            quint8 i5 = (hash) % 255;
+            quint8 i6 = (hash / (i + 2)) % 255; // Under some corner cases i might be -1 or 0
+            shade.setColorAt(1, QColor(i1, i2, i3, 255));
+            shade.setColorAt(0, QColor(i4, i5, i6, 255));
 
-        QPainter pt(&pb);
-        pt.setCompositionMode(QPainter::CompositionMode_SourceOver);
-        pt.fillRect(QRect(0, 0, 120, 30), shade);
-        QPixmap pg(QStringLiteral(":/icons/mudlet_main_32px.png"));
-        pt.drawPixmap(QRect(5, 5, 20, 20), pg);
+            QPainter pt(&pb);
+            pt.setCompositionMode(QPainter::CompositionMode_SourceOver);
+            pt.fillRect(QRect(0, 0, 120, 30), shade);
+            QPixmap pg(QStringLiteral(":/icons/mudlet_main_32px.png"));
+            pt.drawPixmap(QRect(5, 5, 20, 20), pg);
 
-        QFont _font;
-        QImage _pm(90, 30, QImage::Format_ARGB32_Premultiplied);
-        QPainter _pt(&_pm);
-        _pt.setCompositionMode(QPainter::CompositionMode_SourceOver);
-        int fs = 30;
-        for (; fs > 1; fs--) {
-            _pt.eraseRect(QRect(0, 0, 90, 30));
-            _pt.fillRect(QRect(0, 0, 90, 30), QColor(255, 0, 0, 10));
-            _font = QFont(QStringLiteral("DejaVu Sans"), fs, QFont::Normal);
-            _pt.setFont(_font);
+            QFont _font;
+            QImage _pm(90, 30, QImage::Format_ARGB32_Premultiplied);
+            QPainter _pt(&_pm);
+            _pt.setCompositionMode(QPainter::CompositionMode_SourceOver);
+            int fs = 30;
+            for (; fs > 1; fs--) {
+                _pt.eraseRect(QRect(0, 0, 90, 30));
+                _pt.fillRect(QRect(0, 0, 90, 30), QColor(255, 0, 0, 10));
+                _font = QFont(QStringLiteral("DejaVu Sans"), fs, QFont::Normal);
+                _pt.setFont(_font);
+                QRect _r;
+                if ((i1 + i2 + i3 + i4 + i5 + i6) / 6 < 100) {
+                    _pt.setPen(QColor(Qt::white));
+                } else {
+                    _pt.setPen(QColor(Qt::black));
+                }
+                _pt.drawText(QRect(0, 0, 90, 30), Qt::AlignHCenter | Qt::AlignVCenter | Qt::TextWordWrap, s, &_r);
+                /*if( QFontMetrics( _font ).boundingRect( s ).width() <= 80
+                   && QFontMetrics( _font ).boundingRect( s ).height() <= 30 )*/
+                if (_r.width() <= 90 && _r.height() <= 30) {
+                    break;
+                }
+            }
+            pt.setFont(_font);
             QRect _r;
             if ((i1 + i2 + i3 + i4 + i5 + i6) / 6 < 100) {
-                _pt.setPen(QColor(Qt::white));
+                pt.setPen(QColor(Qt::white));
             } else {
-                _pt.setPen(QColor(Qt::black));
-            }
-            _pt.drawText(QRect(0, 0, 90, 30), Qt::AlignHCenter | Qt::AlignVCenter | Qt::TextWordWrap, s, &_r);
-            /*if( QFontMetrics( _font ).boundingRect( s ).width() <= 80
-			   && QFontMetrics( _font ).boundingRect( s ).height() <= 30 )*/
-            if (_r.width() <= 90 && _r.height() <= 30) {
-                break;
+                pt.setPen(QColor(Qt::black));
             }
+            pt.drawText(QRect(30, 0, 90, 30), Qt::AlignHCenter | Qt::AlignVCenter | Qt::TextWordWrap, s, &_r);
+            QIcon mi = QIcon(pb);
+            pItem->setIcon(mi);
         }
-        pt.setFont(_font);
-        QRect _r;
-        if ((i1 + i2 + i3 + i4 + i5 + i6) / 6 < 100) {
-            pt.setPen(QColor(Qt::white));
-        } else {
-            pt.setPen(QColor(Qt::black));
-        }
-        pt.drawText(QRect(30, 0, 90, 30), Qt::AlignHCenter | Qt::AlignVCenter | Qt::TextWordWrap, s, &_r);
-        QIcon mi = QIcon(pb);
-        pItem->setIcon(mi);
     }
 }
 
@@ -484,8 +496,17 @@ void dlgConnectionProfiles::slot_deleteprofile_check(const QString text)
 void dlgConnectionProfiles::slot_reallyDeleteProfile()
 {
     QString profile = profiles_tree_widget->currentItem()->text();
-    QDir dir(QStringLiteral("%1/.config/mudlet/profiles/%2").arg(QDir::homePath(), profile));
-    dir.removeRecursively(); // note: we should replace this with a function that pops up a progress dialog should the deletion be taking longer than a second
+    QDir dir(mudlet::getMudletPath(mudlet::profileHomePath, profile));
+    dir.removeRecursively();
+
+    // record the deleted default profile so it does not get re-created in the future
+    auto& settings = *mudlet::self()->mpSettings;
+    auto deletedDefaultMuds = settings.value(QStringLiteral("deletedDefaultMuds"), QStringList()).toStringList();
+    if (!deletedDefaultMuds.contains(profile)) {
+        deletedDefaultMuds.append(profile);
+    }
+    settings.setValue(QStringLiteral("deletedDefaultMuds"), deletedDefaultMuds);
+
     fillout_form();
     profiles_tree_widget->setFocus();
 }
@@ -523,7 +544,7 @@ void dlgConnectionProfiles::slot_deleteProfile()
     connect(delete_profile_dialog, SIGNAL(accepted()), this, SLOT(slot_reallyDeleteProfile()));
 
     delete_profile_lineedit->setPlaceholderText(profile);
-    cancel_button->setFocus();
+    delete_profile_lineedit->setFocus();
     delete_button->setDisabled(true);
     delete_profile_dialog->setWindowTitle(tr("Deleting '%1'").arg(profile));
 
@@ -533,7 +554,7 @@ void dlgConnectionProfiles::slot_deleteProfile()
 
 QString dlgConnectionProfiles::readProfileData(QString profile, QString item)
 {
-    QFile file(QStringLiteral("%1/.config/mudlet/profiles/%2/%3").arg(QDir::homePath(), profile, item));
+    QFile file(mudlet::getMudletPath(mudlet::profileDataItemPath, profile, item));
     bool success = file.open(QIODevice::ReadOnly);
     QString ret;
     if (success) {
@@ -545,24 +566,9 @@ QString dlgConnectionProfiles::readProfileData(QString profile, QString item)
     return ret;
 }
 
-QStringList dlgConnectionProfiles::readProfileHistory(QString profile, QString item)
-{
-    QFile file(QStringLiteral("%1/.config/mudlet/profiles/%2/%3").arg(QDir::homePath(), profile, item));
-    file.open(QIODevice::ReadOnly);
-    QDataStream ifs(&file);
-    QString ret;
-    QStringList historyList;
-    while (ifs.status() == QDataStream::Ok) {
-        ifs >> ret;
-        historyList << ret;
-    }
-    file.close();
-    return historyList;
-}
-
 QPair<bool, QString> dlgConnectionProfiles::writeProfileData(const QString& profile, const QString& item, const QString& what)
 {
-    QFile file(QStringLiteral("%1/.config/mudlet/profiles/%2/%3").arg(QDir::homePath(), profile, item));
+    QFile file(mudlet::getMudletPath(mudlet::profileDataItemPath, profile, item));
     if (file.open(QIODevice::WriteOnly | QIODevice::Unbuffered)) {
         QDataStream ofs(&file);
         ofs << what;
@@ -831,28 +837,30 @@ void dlgConnectionProfiles::slot_item_clicked(QListWidgetItem* pItem)
 
     profile_history->clear();
 
-    QDir dir(QStringLiteral("%1/.config/mudlet/profiles/%2/current/").arg(QDir::homePath(), profile_name));
+    QDir dir(mudlet::getMudletPath(mudlet::profileXmlFilesPath, profile_name));
     dir.setSorting(QDir::Time);
     QStringList entries = dir.entryList(QDir::Files | QDir::NoDotAndDotDot, QDir::Time);
 
     for (int i = 0; i < entries.size(); ++i) {
-        QRegExp rx(QStringLiteral("(\\d+)\\-(\\d+)\\-(\\d+)#(\\d+)\\-(\\d+)\\-(\\d+).xml"));
-        if (rx.indexIn(entries.at(i)) != -1) {
+        QRegularExpression rx(QStringLiteral("(\\d+)\\-(\\d+)\\-(\\d+)#(\\d+)\\-(\\d+)\\-(\\d+).xml"));
+        QRegularExpressionMatch match = rx.match(entries.at(i));
+
+        if (match.capturedStart() != -1) {
             QString day;
-            QString month = rx.cap(2);
+            QString month = match.captured(2);
             QString year;
-            QString hour = rx.cap(4);
-            QString minute = rx.cap(5);
-            QString second = rx.cap(6);
-            if (rx.cap(1).toInt() > 31 && rx.cap(3).toInt() >= 1 && rx.cap(3).toInt() <= 31) {
+            QString hour = match.captured(4);
+            QString minute = match.captured(5);
+            QString second = match.captured(6);
+            if (match.captured(1).toInt() > 31 && match.captured(3).toInt() >= 1 && match.captured(3).toInt() <= 31) {
                 // I have been experimenting with code that puts the year first
                 // which is actually quite useful - this accommodates such cases
                 // as well... - SlySven
-                year = rx.cap(1);
-                day = rx.cap(3);
+                year = match.captured(1);
+                day = match.captured(3);
             } else {
-                day = rx.cap(1);
-                year = rx.cap(3);
+                day = match.captured(1);
+                year = match.captured(3);
             }
 
 
@@ -922,7 +930,7 @@ void dlgConnectionProfiles::fillout_form()
     host_name_entry->clear();
     port_entry->clear();
 
-    mProfileList = QDir(QStringLiteral("%1/.config/mudlet/profiles").arg(QDir::homePath())).entryList(QDir::Dirs | QDir::NoDotAndDotDot, QDir::Name);
+    mProfileList = QDir(mudlet::getMudletPath(mudlet::profilesPath)).entryList(QDir::Dirs | QDir::NoDotAndDotDot, QDir::Name);
 
     // if only the default_host is present it means no profiles have yet been created
     if (mProfileList.isEmpty() || (mProfileList.size() == 1 && mProfileList.at(0) == QStringLiteral("default_host"))) {
@@ -955,208 +963,244 @@ void dlgConnectionProfiles::fillout_form()
     // we use - unfortunately we currently need that text programmatically at
     // present to identify each item - more work is needed, and is plausable, to
     // completely resolve this. -Slysven
-    QString mudServer;
+    QString mudServer, description;
     QListWidgetItem* pM;
     QIcon mi;
 
+    auto &settings = *mudlet::self()->mpSettings;
+    auto deletedDefaultMuds = settings.value(QStringLiteral("deletedDefaultMuds"), QStringList()).toStringList();
 
     mudServer = QStringLiteral("Avalon.de");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    QPixmap p(QStringLiteral(":/icons/avalon.png"));
-    mi = QIcon(p.scaled(QSize(120, 30)));
-    pM->setIcon(mi);
-    QString description = getDescription(QStringLiteral("avalon.mud.de"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        QPixmap p(QStringLiteral(":/icons/avalon.png"));
+        mi = QIcon(p.scaled(QSize(120, 30)));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("avalon.mud.de"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("Achaea");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QStringLiteral(":/icons/achaea_120_30.png"));
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("achaea.com"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QStringLiteral(":/icons/achaea_120_30.png"));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("achaea.com"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("3Kingdoms");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    QPixmap pd(QStringLiteral(":/icons/3klogo.png"));
-    QPixmap pd1 = pd.scaled(QSize(120, 30), Qt::IgnoreAspectRatio, Qt::SmoothTransformation).copy();
-    QIcon mi5(pd1);
-    pM->setIcon(mi5);
-    description = getDescription(QStringLiteral("3k.org"), 3000, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        QPixmap pd(QStringLiteral(":/icons/3klogo.png"));
+        QPixmap pd1 = pd.scaled(QSize(120, 30), Qt::IgnoreAspectRatio, Qt::SmoothTransformation).copy();
+        QIcon mi5(pd1);
+        pM->setIcon(mi5);
+        description = getDescription(QStringLiteral("3k.org"), 3000, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("3Scapes");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    QPixmap pc(QStringLiteral(":/icons/3slogo.png"));
-    QPixmap pc1 = pc.scaled(QSize(120, 30), Qt::IgnoreAspectRatio, Qt::SmoothTransformation).copy();
-    QIcon mi4(pc1);
-    pM->setIcon(mi4);
-    description = getDescription(QStringLiteral("3k.org"), 3200, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        QPixmap pc(QStringLiteral(":/icons/3slogo.png"));
+        QPixmap pc1 = pc.scaled(QSize(120, 30), Qt::IgnoreAspectRatio, Qt::SmoothTransformation).copy();
+        QIcon mi4(pc1);
+        pM->setIcon(mi4);
+        description = getDescription(QStringLiteral("3k.org"), 3200, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("Lusternia");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QStringLiteral(":/icons/lusternia_120_30.png"));
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("lusternia.com"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QStringLiteral(":/icons/lusternia_120_30.png"));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("lusternia.com"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("BatMUD");
-    QPixmap pb(QStringLiteral(":/icons/batmud_mud.png"));
-    QPixmap pb1 = pb.scaled(QSize(120, 30)).copy();
-    mi = QIcon(pb1);
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("batmud.bat.org"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        QPixmap pb(QStringLiteral(":/icons/batmud_mud.png"));
+        QPixmap pb1 = pb.scaled(QSize(120, 30)).copy();
+        mi = QIcon(pb1);
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("batmud.bat.org"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("God Wars II");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QStringLiteral(":/icons/gw2.png"));
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("godwars2.org"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QStringLiteral(":/icons/gw2.png"));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("godwars2.org"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("Slothmud");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QStringLiteral(":/icons/Slothmud.png"));
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("slothmud.org"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QStringLiteral(":/icons/Slothmud.png"));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("slothmud.org"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("Aardwolf");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QStringLiteral(":/icons/aardwolf_mud.png"));
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("aardmud.org"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QStringLiteral(":/icons/aardwolf_mud.png"));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("aardmud.org"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("Materia Magica");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QStringLiteral(":/materiaMagicaIcon"));
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("materiamagica.com"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QStringLiteral(":/materiaMagicaIcon"));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("materiamagica.com"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("Realms of Despair");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QStringLiteral(":/icons/120x30RoDLogo.png"));
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("realmsofdespair.com"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QStringLiteral(":/icons/120x30RoDLogo.png"));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("realmsofdespair.com"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("ZombieMUD");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QStringLiteral(":/icons/zombiemud.png"));
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("zombiemud.org"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QStringLiteral(":/icons/zombiemud.png"));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("zombiemud.org"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("Aetolia");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QStringLiteral(":/icons/aetolia_120_30.png"));
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("aetolia.com"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QStringLiteral(":/icons/aetolia_120_30.png"));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("aetolia.com"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("Imperian");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QStringLiteral(":/icons/imperian_120_30.png"));
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("imperian.com"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QStringLiteral(":/icons/imperian_120_30.png"));
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("imperian.com"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("WoTMUD");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QPixmap(QStringLiteral(":/icons/wotmudicon.png")).scaled(QSize(120, 30), Qt::IgnoreAspectRatio, Qt::SmoothTransformation).copy());
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("game.wotmud.org"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QPixmap(QStringLiteral(":/icons/wotmudicon.png")).scaled(QSize(120, 30), Qt::IgnoreAspectRatio,
+                                                                            Qt::SmoothTransformation).copy());
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("game.wotmud.org"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     mudServer = QStringLiteral("Midnight Sun 2");
-    pM = new QListWidgetItem(mudServer);
-    pM->setFont(font);
-    pM->setForeground(QColor(Qt::white));
-    profiles_tree_widget->addItem(pM);
-    mi = QIcon(QPixmap(QStringLiteral(":/icons/midnightsun2.png")).scaled(QSize(120, 30), Qt::IgnoreAspectRatio, Qt::SmoothTransformation).copy());
-    pM->setIcon(mi);
-    description = getDescription(QStringLiteral("midnightsun2.org"), 0, mudServer);
-    if (!description.isEmpty()) {
-        pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+    if (!deletedDefaultMuds.contains(mudServer)) {
+        pM = new QListWidgetItem(mudServer);
+        pM->setFont(font);
+        pM->setForeground(QColor(Qt::white));
+        profiles_tree_widget->addItem(pM);
+        mi = QIcon(QPixmap(QStringLiteral(":/icons/midnightsun2.png")).scaled(QSize(120, 30), Qt::IgnoreAspectRatio,
+                                                                              Qt::SmoothTransformation).copy());
+        pM->setIcon(mi);
+        description = getDescription(QStringLiteral("midnightsun2.org"), 0, mudServer);
+        if (!description.isEmpty()) {
+            pM->setToolTip(QLatin1String("<html><head/><body><p>") % description % QLatin1String("</p></body></html>"));
+        }
     }
 
     for (int i = 0; i < mProfileList.size(); i++) {
@@ -1168,10 +1212,9 @@ void dlgConnectionProfiles::fillout_form()
         auto pItem = new QListWidgetItem(mProfileList.at(i));
 
         // mProfileList is derived from a filesystem directory, but MacOS is not
-        // necesserily case preserving for file names so any tests on them
-        // should be case insensitive...! - Slysven
-        // Change from using a "==" test to a QString::compare( const QString )
-        // which returns a 0 on a match or +/-1 on difference
+        // necessarily case preserving for file names so any tests on them
+        // should be case insensitive
+        // skip creating icons for default MUDs as they are already created above
         if ((!mProfileList.at(i).compare(QStringLiteral("Avalon.de"), Qt::CaseInsensitive)) || (!mProfileList.at(i).compare(QStringLiteral("BatMUD"), Qt::CaseInsensitive))
             || (!mProfileList.at(i).compare(QStringLiteral("Materia Magica"), Qt::CaseInsensitive))
             || (!mProfileList.at(i).compare(QStringLiteral("Aardwolf"), Qt::CaseInsensitive))
@@ -1185,6 +1228,7 @@ void dlgConnectionProfiles::fillout_form()
             || (!mProfileList.at(i).compare(QStringLiteral("3Kingdoms"), Qt::CaseInsensitive))
             || (!mProfileList.at(i).compare(QStringLiteral("Midnight Sun 2"), Qt::CaseInsensitive))
             || (!mProfileList.at(i).compare(QStringLiteral("WoTMUD"), Qt::CaseInsensitive))) {
+            delete pItem;
             continue;
         }
 
@@ -1252,7 +1296,7 @@ void dlgConnectionProfiles::fillout_form()
         auto profile = profiles_tree_widget->item(i);
         auto profileName = profile->text();
 
-        QDateTime profile_lastRead = QFileInfo(QStringLiteral("%1/.config/mudlet/profiles/%2/current/").arg(QDir::homePath(), profileName)).lastModified();
+        QDateTime profile_lastRead = QFileInfo(mudlet::getMudletPath(mudlet::profileXmlFilesPath, profileName)).lastModified();
         // Since Qt 5.x null QTimes and QDateTimes are invalid - and might not
         // work as expected - so test for validity of the test_date value as well
         if ((!test_date.isValid()) || profile_lastRead > test_date) {
@@ -1262,7 +1306,7 @@ void dlgConnectionProfiles::fillout_form()
         }
     }
 
-    if (toselectRow != -1 && toselectProfileName == QStringLiteral("default_host")) {
+    if (toselectRow != -1 && toselectProfileName == QStringLiteral("default_host") && profiles_tree_widget->count() > 1) {
         // if the last profile read is default_host, it means the user hasn't created
         // any profiles yet since default_host profile cannot actually be used. In this case,
         // select a random pre-defined profile to give all MUDs a fair go
@@ -1328,12 +1372,13 @@ void dlgConnectionProfiles::slot_copy_profile()
     port_entry->setReadOnly(false);
 
     // copy the folder on-disk
-    QDir dir(QStringLiteral("%1/.config/mudlet/profiles/%2").arg(QDir::homePath(), oldname));
+    QDir dir(mudlet::getMudletPath(mudlet::profileHomePath, oldname));
     if (!dir.exists()) {
         return;
     }
 
-    copyFolder(QStringLiteral("%1/.config/mudlet/profiles/%2").arg(QDir::homePath(), oldname), QStringLiteral("%1/.config/mudlet/profiles/%2").arg(QDir::homePath(), profile_name));
+    copyFolder(mudlet::getMudletPath(mudlet::profileHomePath, oldname),
+               mudlet::getMudletPath(mudlet::profileHomePath, profile_name));
     mProfileList << profile_name;
     slot_item_clicked(pItem);
 }
@@ -1346,21 +1391,25 @@ void dlgConnectionProfiles::slot_connectToServer()
         return;
     }
 
-    Host* pHost = mudlet::self()->getHostManager().getHost(profile_name);
+    HostManager & hostManager = mudlet::self()->getHostManager();
+    Host* pHost = hostManager.getHost(profile_name);
     if (pHost) {
         pHost->mTelnet.connectIt(pHost->getUrl(), pHost->getPort());
         QDialog::accept();
         return;
     }
     // load an old profile if there is any
-    mudlet::self()->getHostManager().addHost(profile_name, port_entry->text().trimmed(), QString(), QString());
-    pHost = mudlet::self()->getHostManager().getHost(profile_name);
-
-    if (!pHost) {
+    // PLACEMARKER: Host creation (3) - normal case
+    if (hostManager.addHost(profile_name, port_entry->text().trimmed(), QString(), QString())) {
+        pHost = hostManager.getHost(profile_name);
+        if (!pHost) {
+            return;
+        }
+    } else {
         return;
     }
 
-    QString folder = QStringLiteral("%1/.config/mudlet/profiles/%2/current/").arg(QDir::homePath(), profile_name);
+    QString folder(mudlet::getMudletPath(mudlet::profileXmlFilesPath, profile_name));
     QDir dir(folder);
     dir.setSorting(QDir::Time);
     QStringList entries = dir.entryList(QDir::Files, QDir::Time);
@@ -1372,7 +1421,7 @@ void dlgConnectionProfiles::slot_connectToServer()
         file.open(QFile::ReadOnly | QFile::Text);
         XMLimport importer(pHost);
         qDebug() << "[LOADING PROFILE]:" << file.fileName();
-        importer.importPackage(&file, 0); // TODO: Missing false return value handler
+        importer.importPackage(&file, nullptr); // TODO: Missing false return value handler
     } else {
         needsGenericPackagesInstall = true;
     }
@@ -1424,6 +1473,7 @@ void dlgConnectionProfiles::slot_connectToServer()
         mudlet::self()->packagesToInstallList.append(QStringLiteral(":/run-lua-code-v4.xml"));
     }
 
+    emit mudlet::self()->signal_hostCreated(pHost, hostManager.getHostCount());
     emit signal_establish_connection(profile_name, 0);
 }
 
