@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2012-2013 by Heiko Koehn - KoehnHeiko@googlemail.com    *
  *   Copyright (C) 2014 by Ahmed Charles - acharles@outlook.com            *
- *   Copyright (C) 2015 by Stephen Lyons - slysven@virginmedia.com         *
+ *   Copyright (C) 2015, 2017 by Stephen Lyons - slysven@virginmedia.com   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,6 +23,7 @@
 #include "dlgPackageExporter.h"
 
 
+#include "mudlet.h"
 #include "Host.h"
 #include "TAction.h"
 #include "TAlias.h"
@@ -74,17 +75,17 @@ dlgPackageExporter::dlgPackageExporter(QWidget *parent, Host* host) :
     // reset zipFile and filePath from possible previous use
     zipFile = filePath = "";
 
-    packageName = QInputDialog::getText(0, "Package name", "Package name:");
+    packageName = QInputDialog::getText(nullptr, "Package name", "Package name:");
     if (packageName.isEmpty()) {
         return;
     }
-    QString packagePath = QFileDialog::getExistingDirectory(0, "Where do you want to save the package?", "Where do you want to save the package?");
+    QString packagePath = QFileDialog::getExistingDirectory(nullptr, "Where do you want to save the package?", "Where do you want to save the package?");
     if (packagePath.isEmpty()) {
         return;
     }
-
-    tempDir = QDir::homePath() + "/.config/mudlet/profiles/" + mpHost->getName() + "/tmp/";
     packagePath.replace(R"(\)", "/");
+
+    tempDir = mudlet::getMudletPath(mudlet::profileDataItemPath, mpHost->getName(), QStringLiteral("/tmp/"));
     tempDir = tempDir + "/" + packageName;
     QDir packageDir = QDir(tempDir);
     if (!packageDir.exists()) {
@@ -279,7 +280,7 @@ void dlgPackageExporter::slot_export_package()
             }
             QString fullName = tempDir + "/" + contents[i];
             struct zip_source* s = zip_source_file(archive, fullName.toStdString().c_str(), 0, 0);
-            if (s == NULL) {
+            if (s == nullptr) {
                 int sep = 0;
                 zip_error_get(archive, &err, &sep);
                 zip_error_to_str(buf, sizeof(buf), err, errno);
