@@ -27,19 +27,23 @@
 
 #include "HostManager.h"
 
-#include "pre_guard.h"
-#include "ui_main_window.h"
 #include "edbee/views/texttheme.h"
+#include "ui_main_window.h"
+#if defined(INCLUDE_UPDATER)
+#include "updater.h"
+#endif
+#include "pre_guard.h"
 #include <QFlags>
 #include <QMainWindow>
 #include <QMap>
 #include <QMediaPlayer>
 #include <QPointer>
 #include <QQueue>
+#include <QSettings>
 #include <QTextOption>
 #include <QTime>
 #ifdef QT_GAMEPAD_LIB
-  #include <QGamepad>
+#include <QGamepad>
 #endif
 #include "post_guard.h"
 
@@ -68,19 +72,19 @@ class dlgAboutDialog;
 class dlgProfilePreferences;
 
 
-class mudlet : public QMainWindow, public Ui::MainWindow
+class mudlet : public QMainWindow, public Ui::main_window
 {
     Q_OBJECT
 
-    Q_DISABLE_COPY(mudlet)
-
 public:
+    Q_DISABLE_COPY(mudlet)
     mudlet();
     ~mudlet();
     static mudlet* self();
     // This method allows better debugging when mudlet::self() is called inappropriately.
     static void start();
     HostManager& getHostManager() { return mHostManager; }
+    QPointer<QSettings> mpSettings;
     void addSubWindow(TConsole* p);
     int getColumnNumber(Host* pHost, QString& name);
     int getLineNumber(Host* pHost, QString& name);
@@ -98,6 +102,8 @@ public:
     void setDockLayoutUpdated(Host*, const QString&);
     void setToolbarLayoutUpdated(Host*, TToolBar*);
     void commitLayoutUpdates();
+    bool setFontSize(Host*, const QString&, int);
+    int getFontSize(Host*, const QString&);
     bool openWindow(Host*, const QString&, bool loadLayout = true);
     bool createMiniConsole(Host*, const QString&, int, int, int, int);
     bool createLabel(Host*, const QString&, int, int, int, int, bool);
@@ -117,7 +123,10 @@ public:
     bool setBackgroundImage(Host*, const QString& name, QString& path);
     bool setTextFormat(Host*, const QString& name, int, int, int, int, int, int, bool, bool, bool, bool);
     bool setLabelClickCallback(Host*, const QString&, const QString&, const TEvent&);
+    bool setLabelDoubleClickCallback(Host*, const QString&, const QString&, const TEvent&);
     bool setLabelReleaseCallback(Host*, const QString&, const QString&, const TEvent&);
+    bool setLabelMoveCallback(Host*, const QString&, const QString&, const TEvent&);
+    bool setLabelWheelCallback(Host*, const QString&, const QString&, const TEvent&);
     bool setLabelOnEnter(Host*, const QString&, const QString&, const TEvent&);
     bool setLabelOnLeave(Host*, const QString&, const QString&, const TEvent&);
     bool moveWindow(Host*, const QString& name, int, int);
@@ -140,13 +149,14 @@ public:
     bool moveCursorEnd(Host*, const QString&);
     bool moveCursor(Host*, const QString&, int, int);
     int getLastLineNumber(Host*, const QString&);
-    void readSettings();
+    void readSettings(const QSettings&);
     void writeSettings();
     bool openWebPage(const QString& path);
+    void checkUpdatesOnStart();
     void processEventLoopHack();
     static const QString scmMudletXmlDefaultVersion;
     static QPointer<TConsole> mpDebugConsole;
-    static QMainWindow* mpDebugArea;
+    static QPointer<QMainWindow> mpDebugArea;
     static bool debugMode;
     QMap<Host*, TConsole*> mConsoleMap;
     QMap<Host*, QMap<QString, TConsole*>> mHostConsoleMap;
@@ -156,11 +166,15 @@ public:
     bool mShowMenuBar;
     bool mShowToolbar;
     bool isGoingDown() { return mIsGoingDown; }
-    int mMainIconSize;
-    int mTEFolderIconSize;
-    void setIcoSize(int s);
+    int mToolbarIconSize;
+    int mEditorTreeWidgetIconSize;
+    void setToolBarIconSize(const int);
+    void setEditorTreeWidgetIconSize(const int);
+    void setToolBarVisible(const bool);
+    void setMenuBarVisible(const bool);
     void replayStart();
     bool setConsoleBufferSize(Host* pHost, const QString& name, int x1, int y1);
+    bool setScrollBarVisible(Host* pHost, const QString& name, bool isVisible);
     void replayOver();
     void showEvent(QShowEvent* event) override;
     void hideEvent(QHideEvent* event) override;
@@ -171,6 +185,10 @@ public:
     bool deselect(Host* pHost, const QString& name);
     void stopSounds();
     void playSound(QString s, int);
+    int getColumnCount(Host* pHost, QString& name);
+    int getRowCount(Host* pHost, QString& name);
+
+    static const bool scmIsDevelopmentVersion;
     QTime mReplayTime;
     int mReplaySpeed;
     QToolBar* mpMainToolBar;
@@ -197,18 +215,93 @@ public:
     // are considered/used/stored
     QTextOption::Flags mEditorTextOptions;
     void setEditorTextoptions(const bool isTabsAndSpacesToBeShown, const bool isLinesAndParagraphsToBeShown);
-    static bool loadEdbeeTheme(const QString &themeName, const QString &themeFile);
+    static bool loadEdbeeTheme(const QString& themeName, const QString& themeFile);
 
     // Used by a profile to tell the mudlet class
     // to tell other profiles to reload the updated
     // maps (via signal_profileMapReloadRequested(...))
     void requestProfilesToReloadMaps(QList<QString>);
 
+    void showChangelogIfUpdated();
+
     bool showMapAuditErrors() const { return mshowMapAuditErrors; }
     void setShowMapAuditErrors(const bool state) { mshowMapAuditErrors = state; }
+    bool compactInputLine() const { return mCompactInputLine; }
+    void setCompactInputLine(const bool state) { mCompactInputLine = state; }
     void createMapper(bool loadDefaultMap = true);
 
-    static bool unzip(const QString &archivePath, const QString &destination, const QDir &tmpDir);
+    static bool unzip(const QString& archivePath, const QString& destination, const QDir& tmpDir);
+
+    enum mudletPathType {
+        // The root of all mudlet data for the user - does not end in a '/'
+        mainPath = 0,
+        // Takes one extra argument as a file (or directory) relating to
+        // (profile independent) mudlet data - may end with a '/' if the extra
+        // argument does:
+        mainDataItemPath,
+        // (Added for 3.5.0) a revised location to store Mudlet provided fonts:
+        mainFontsPath,
+        // The directory containing all the saved user's profiles - does not end
+        // in '/':
+        profilesPath,
+        // Takes one extra argument (profile name) that returns the base
+        // directory for that profile - does NOT end in a '/' unless the
+        // supplied profle name does:
+        profileHomePath,
+        // Takes one extra argument (profile name) that returns the directory
+        // for the profile game save XML files - ends in a '/':
+        profileXmlFilesPath,
+        // Takes one extra argument (profile name) that returns the directory
+        // for the profile game save maps files - does NOT end in a '/'
+        profileMapsPath,
+        // Takes two extra arguments (profile name, dataTime stamp) that returns
+        // the pathFile name for a dateTime stamped map file:
+        profileDateTimeStampedMapPathFileName,
+        // Takes two extra arguments (profile name, mapFileName) that returns
+        // the pathFile name for any map file:
+        profileMapPathFileName,
+        // Takes one extra argument (profile name) that returns the pathFile
+        // name for the downloaded IRE Server provided XML map:
+        profileXmlMapPathFileName,
+        // Takes two extra arguments (profile name, data item) that gives a
+        // path file name for, typically a data item stored as a single item
+        // (binary) profile data) file (ideally these can be moved to a per
+        // profile QSettings file but that is a future pipe-dream on my part
+        // SlySven):
+        profileDataItemPath,
+        // Takes two extra arguments (profile name, package name) returns the
+        // per profile directory used to store (unpacked) package contents
+        // - ends with a '/':
+        profilePackagePath,
+        // Takes two extra arguments (profile name, package name) returns the
+        // filename of the XML file that contains the (per profile, unpacked)
+        // package mudlet items in that package/module:
+        profilePackagePathFileName,
+        // Takes one extra argument (profile name) that returns the directory
+        // that contains replays (*.dat files) and logs (*.html or *.txt) files
+        // for that profile - does NOT end in '/':
+        profileReplayAndLogFilesPath,
+        // Takes one extra argument (profile name) that returns the pathFileName
+        // to the map auditing report file that is appended to each time a
+        // map is loaded:
+        profileLogErrorsFilePath,
+        // Takes two extra arguments (profile name, theme name) that returns the
+        // pathFileName of the theme file used by the edbee editor - also
+        // handles the special case of the default theme "mudlet.thTheme" that
+        // is carried internally in the resource file:
+        editorWidgetThemePathFile,
+        // Returns the pathFileName to the external JSON file needed to process
+        // an edbee edtor widget theme:
+        editorWidgetThemeJsonFile,
+        // Returns the directory used to store module backups that is used in
+        // when saving/resyncing packages/modules - ends in a '/'
+        moduleBackupsPath
+    };
+    static QString getMudletPath(const mudletPathType, const QString& extra1 = QString(), const QString& extra2 = QString());
+
+#if defined(INCLUDE_UPDATER)
+    Updater* updater;
+#endif
 
 public slots:
     void processEventLoopHack_timerRun();
@@ -222,12 +315,10 @@ public slots:
     void slot_show_help_dialog_video();
     void slot_show_help_dialog_forum();
     void slot_show_help_dialog_irc();
-    void slot_show_help_dialog_download();
     void slot_open_mappingscripts_page();
     void slot_module_clicked(QTableWidgetItem*);
     void slot_module_changed(QTableWidgetItem*);
     void slot_multi_view();
-    void slot_stopAllTriggers();
     void slot_userToolBar_hovered(QAction* pA);
     void slot_connection_dlg_finished(const QString& profile, int historyVersion);
     void slot_timer_fires();
@@ -249,6 +340,9 @@ public slots:
     void slot_module_manager();
     void layoutModules();
     void slot_help_module();
+#if defined(INCLUDE_UPDATER)
+    void slot_check_manual_update();
+#endif
 
 protected:
     void closeEvent(QCloseEvent* event) override;
@@ -256,6 +350,10 @@ protected:
 signals:
     void signal_editorTextOptionsChanged(QTextOption::Flags);
     void signal_profileMapReloadRequested(QList<QString>);
+    void signal_setToolBarIconSize(const int);
+    void signal_setTreeIconSize(const int);
+    void signal_hostCreated(Host*, const quint8);
+    void signal_hostDestroyed(Host*, const quint8);
 
 private slots:
     void slot_close_profile();
@@ -277,6 +375,10 @@ private slots:
     void slot_gamepadDisconnected(int deviceId);
     void slot_gamepadAxisEvent(int deviceId, QGamepadManager::GamepadAxis axis, double value);
 #endif
+    void slot_module_manager_destroyed();
+#if defined(INCLUDE_UPDATER)
+    void slot_update_installed();
+#endif
 
 private:
     void initEdbee();
@@ -291,8 +393,6 @@ private:
     QQueue<Host*> tempHostQueue;
     static QPointer<mudlet> _self;
     QMap<Host*, QToolBar*> mUserToolbarMap;
-
-
     QMenu* restoreBar;
     bool mIsGoingDown;
 
@@ -309,27 +409,33 @@ private:
 
     void check_for_mappingscript();
 
-    QListWidget* packageList;
-    QPushButton* uninstallButton;
-    QPushButton* installButton;
+    QPointer<QListWidget> packageList;
+    QPointer<QPushButton> uninstallButton;
+    QPointer<QPushButton> installButton;
 
-    QTableWidget* moduleTable;
-    QPushButton* moduleUninstallButton;
-    QPushButton* moduleInstallButton;
-    QPushButton* moduleHelpButton;
+    QPointer<Host> mpModuleTableHost;
+    QPointer<QTableWidget> moduleTable;
+    QPointer<QPushButton> moduleUninstallButton;
+    QPointer<QPushButton> moduleInstallButton;
+    QPointer<QPushButton> moduleHelpButton;
 
     HostManager mHostManager;
 
     bool mshowMapAuditErrors;
+
+    bool mCompactInputLine;
+    void slot_toggle_compact_input_line();
+    void set_compact_input_line();
+
+    QSettings* getQSettings();
 };
 
 class TConsoleMonitor : public QObject
 {
     Q_OBJECT
 
-    Q_DISABLE_COPY(TConsoleMonitor)
-
 public:
+    Q_DISABLE_COPY(TConsoleMonitor)
     TConsoleMonitor(QObject* parent) : QObject(parent) {}
 protected:
     bool eventFilter(QObject* obj, QEvent* event) override;
